@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,7 +73,7 @@ import com.openexchange.subscribe.microformats.parser.OXMFForm;
  */
 public class HTTPFormSubmittingOXMFDataSource implements OXMFDataSource {
     
-    private static final Log LOG = LogFactory.getLog(HTTPFormSubmittingOXMFDataSource.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(HTTPFormSubmittingOXMFDataSource.class));
 
     public Reader getData(Subscription subscription) throws SubscriptionException {
         if(!ExternalSubscriptionSource.class.isInstance(subscription.getSource())) {
@@ -137,6 +137,10 @@ public class HTTPFormSubmittingOXMFDataSource implements OXMFDataSource {
         public Object text(Object... args) {
             return args[0];
         }
+
+        public Object custom(Object... args) {
+            return null;
+        }
         
     }
 
