@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.subscribe.microformats.osgi;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicReference;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.config.ConfigurationService;
@@ -73,7 +74,7 @@ import com.openexchange.timer.TimerService;
  */
 public class ExternalSourcesActivator extends DeferredActivator {
 
-    private static final Log LOG = LogFactory.getLog(ExternalSourcesActivator.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ExternalSourcesActivator.class));
     
     private static final String SOURCES_LIST = "com.openexchange.subscribe.external.sources";
 
@@ -96,18 +97,20 @@ public class ExternalSourcesActivator extends DeferredActivator {
 
     }
 
+    public static final AtomicReference<ConfigurationService> ConfigurationServiceRef = new AtomicReference<ConfigurationService>();
 
     @Override
     protected void startBundle() throws Exception {
+        ConfigurationServiceRef.set(getService(ConfigurationService.class));
         tryConfig();
     }
 
 
     @Override
     protected void stopBundle() throws Exception {
-        
+        ConfigurationServiceRef.set(null);
     }
-    
+
     private void tryConfig() {
         ConfigurationService config = getService(ConfigurationService.class);
         TimerService timer = getService(TimerService.class);
