@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.subscribe.microformats.transformers;
 import java.io.BufferedInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
@@ -80,7 +81,7 @@ public class MapToContactObjectTransformer implements MapToObjectTransformer{
     
     private static final String OXMF_PREFIX = OXMFVisitor.OXMF_PREFIX;
     
-    private static final Log LOG = LogFactory.getLog(MapToContactObjectTransformer.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MapToContactObjectTransformer.class));
     
 	public List<Contact> transform (List<Map<String, String>> inlist){
 		ArrayList<Contact> outlist = new ArrayList<Contact>();
@@ -434,6 +435,12 @@ public class MapToContactObjectTransformer implements MapToObjectTransformer{
             LOG.warn(new StringBuilder(32 + uri.length()).append("Image  URI could not be loaded: ").append(uri).toString(), e);
         }
         if (bytes != null) {
+            final String imimeType = com.openexchange.java.ImageTypeDetector.getMimeType(bytes);
+            if (!imimeType.toLowerCase().startsWith("image/") || com.openexchange.java.HTMLDetector.containsHTMLTags(bytes)) {
+                throw new IllegalStateException("Not a valid image file");
+            } else if (!isValidImage(new com.openexchange.java.UnsynchronizedByteArrayInputStream(bytes))) {
+                throw new IllegalStateException("Not an image file");
+            }
             contactContainer.setImage1(bytes);
             if (mimeType == null) {
                 mimeType = ImageTypeDetector.getMimeType(bytes);
@@ -444,7 +451,16 @@ public class MapToContactObjectTransformer implements MapToObjectTransformer{
             contactContainer.setImageContentType(mimeType);
         }
     }
-	
-	
+
+	/** Checks for a valid image */
+    private static boolean isValidImage(final InputStream data) {
+        java.awt.image.BufferedImage bimg = null;
+        try {
+            bimg = javax.imageio.ImageIO.read(data);
+        } catch (final Exception e) {
+            return false;
+        }
+        return (bimg != null && bimg.getHeight() > 0 && bimg.getWidth() > 0);
+    }	
 
 }
